Bahub
=====

Bahub (Backup Hub) is a shell client for the `File Repository` API.
Allows to totally automate the backups on your server - the API is storing, versioning and rotating your backups, 
this client is sending them in a secure, encrypted way.

Features:
- Automatically schedule docker volumes backup
- Encrypt backups with own key
- Custom backup commands that are producing output to capture
- MySQL backup examples

Copyleft
--------

Created by **RiotKit Collective** as part of Wolnościowiec initiative.
Project initially created for three purposes: 

- To store static files uploaded for users (libertarian/anarchist portal)
- To store and serve video files (video archive)
- To store backups and version them. Limit the disk space and permissions to create a shared space for multiple organizations fighting for human-rights, tenants-rights, working-class rights and animals-rights.
